@@ -28,7 +28,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( CheckDigits );
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 my %methods = (
     'mbase-001'          => 'Algorithm::CheckDigits::MBase_001',
@@ -124,6 +124,11 @@ my %methods = (
     'm11-016'            => 'Algorithm::CheckDigits::M11_016',
     'ustid_pl'           => 'Algorithm::CheckDigits::M11_016',
     'vatrn_pl'           => 'Algorithm::CheckDigits::M11_016',
+    'm11-017'            => 'Algorithm::CheckDigits::M11_017',
+    'ecno'               => 'Algorithm::CheckDigits::M11_017',
+    'ec-no'              => 'Algorithm::CheckDigits::M11_017',
+    'einecs'             => 'Algorithm::CheckDigits::M11_017',
+    'elincs'             => 'Algorithm::CheckDigits::M11_017',
     'm16-001'            => 'Algorithm::CheckDigits::M16_001',
     'isan'               => 'Algorithm::CheckDigits::M16_001',
     'm23-001'            => 'Algorithm::CheckDigits::M23_001',
@@ -394,6 +399,10 @@ See L<Algorithm::CheckDigits::M11_015>.
 
 See L<Algorithm::CheckDigits::M11_016>.
 
+=item ecno, ec-no, einecs, elincs, m11-017
+
+See L<Algorithm::CheckDigits::M11_017>.
+
 =item isan, m16-001
 
 See L<Algorithm::CheckDigits::M16_001>.
